@@ -1,5 +1,5 @@
 /*
- * $Id$
+ * $Id: 5a2a273cbb6105858ebe48190ef2adbcfb5104a1 $
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,6 +21,10 @@
 #ifndef IDENT_H
 #define IDENT_H
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 #if defined(__GNUC__)
 /* force inclusion of ident keywords in the face of optimization */
 #define RCSID(id) static const char rcsid[] __attribute__ ((used)) = id;
@@ -35,4 +39,8 @@
 #define RCSIDH(h, id)
 #endif
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* IDENT_H */
